# DBND Redshift

## The plugin

`dbnd-redshift` logs redshift resource usage of queries using `log_redshift_resource_usage`.

### What does it do?

It uses internal/system redshift tables to get query data after they are completed.

### Installation

```bash
pip install dbnd-redshift
```
